@@ -20,7 +20,7 @@ import datetime
 from mapproxy.util.ext.dictspec.validator import validate, ValidationError
 from mapproxy.util.ext.dictspec.spec import one_of, anything, number
 from mapproxy.util.ext.dictspec.spec import recursive, required, type_spec, combined
-from mapproxy.compat import string_type
+
 
 def validate_options(conf_dict):
     """
@@ -36,6 +36,7 @@ def validate_options(conf_dict):
     else:
         return [], True
 
+
 time_spec = {
     'seconds': number(),
     'minutes': number(),
@@ -115,33 +116,40 @@ riak_node = {
     'http_port': number(),
 }
 
+cache_commons = combined(
+    {
+        'coverage': coverage,
+    }
+)
+
 cache_types = {
-    'file': {
+    'file': combined(cache_commons, {
         'directory_layout': str(),
         'use_grid_names': bool(),
         'directory': str(),
         'tile_lock_dir': str(),
-    },
-    'sqlite': {
+    }),
+    'sqlite': combined(cache_commons, {
         'directory': str(),
         'sqlite_timeout': number(),
         'sqlite_wal': bool(),
         'tile_lock_dir': str(),
-    },
-    'mbtiles': {
+        'ttl': int(),
+    }),
+    'mbtiles': combined(cache_commons, {
         'filename': str(),
         'sqlite_timeout': number(),
         'sqlite_wal': bool(),
         'tile_lock_dir': str(),
-    },
-    'geopackage': {
+    }),
+    'geopackage': combined(cache_commons, {
         'filename': str(),
         'directory': str(),
         'tile_lock_dir': str(),
         'table_name': str(),
         'levels': bool(),
-    },
-    'couchdb': {
+    }),
+    'couchdb': combined(cache_commons, {
         'url': str(),
         'db_name': str(),
         'tile_metadata': {
@@ -149,8 +157,8 @@ cache_types = {
         },
         'tile_id': str(),
         'tile_lock_dir': str(),
-    },
-    's3': {
+    }),
+    's3': combined(cache_commons, {
         'bucket_name': str(),
         'directory_layout': str(),
         'directory': str(),
@@ -159,8 +167,9 @@ cache_types = {
         'endpoint_url': str(),
         'access_control_list': str(),
         'tile_lock_dir': str(),
-     },
-    'riak': {
+        'use_http_get': bool(),
+    }),
+    'riak': combined(cache_commons, {
         'nodes': [riak_node],
         'protocol': one_of('pbc', 'http', 'https'),
         'bucket': str(),
@@ -170,26 +179,31 @@ cache_types = {
         },
         'secondary_index': bool(),
         'tile_lock_dir': str(),
-    },
-    'redis': {
+    }),
+    'redis': combined(cache_commons, {
         'host': str(),
         'port': int(),
+        'password': str(),
+        'username': str(),
         'db': int(),
         'prefix': str(),
         'default_ttl': int(),
-    },
-    'compact': {
+        'ssl_certfile': str(),
+        'ssl_keyfile': str(),
+        'ssl_ca_certs': str(),
+    }),
+    'compact': combined(cache_commons, {
         'directory': str(),
         required('version'): number(),
         'tile_lock_dir': str(),
-    },
-    'azureblob': {
+    }),
+    'azureblob': combined(cache_commons, {
         'connection_string': str(),
         'container_name': str(),
         'directory_layout': str(),
         'directory': str(),
         'tile_lock_dir': str(),
-    },
+    }),
 }
 
 on_error = {
@@ -201,7 +215,6 @@ on_error = {
 }
 
 
-
 inspire_md = {
     'linked': {
         required('metadata_url'): {
@@ -223,7 +236,7 @@ inspire_md = {
             'date_of_last_revision': one_of(str, datetime.date),
         },
         required('conformities'): [{
-            'title': string_type,
+            'title': str,
             'uris': [str],
             'date_of_publication': one_of(str, datetime.date),
             'date_of_creation': one_of(str, datetime.date),
@@ -235,12 +248,12 @@ inspire_md = {
             required('degree'): str,
         }],
         required('metadata_points_of_contact'): [{
-            'organisation_name': string_type,
+            'organisation_name': str,
             'email': str,
         }],
         required('mandatory_keywords'): [str],
         'keywords': [{
-            required('title'): string_type,
+            required('title'): str,
             'date_of_publication': one_of(str, datetime.date),
             'date_of_creation': one_of(str, datetime.date),
             'date_of_last_revision': one_of(str, datetime.date),
@@ -249,7 +262,7 @@ inspire_md = {
                 required('url'): str,
                 required('media_type'): str,
             }],
-            required('keyword_value'): string_type,
+            required('keyword_value'): str,
         }],
         required('metadata_date'): one_of(str, datetime.date),
         'metadata_url': {
@@ -263,28 +276,28 @@ inspire_md = {
 }
 
 wms_130_layer_md = {
-    'abstract': string_type,
+    'abstract': str,
     'keyword_list': [
         {
-            'vocabulary': string_type,
-            'keywords': [string_type],
+            'vocabulary': str,
+            'keywords': [str],
         }
     ],
     'attribution': {
-        'title': string_type,
+        'title': str,
         'url':    str,
         'logo': {
             'url':    str,
             'width':  int,
             'height': int,
-            'format': string_type,
-       }
+            'format': str,
+        }
     },
     'identifier': [
         {
             'url': str,
-            'name': string_type,
-            'value': string_type,
+            'name': str,
+            'value': str,
         }
     ],
     'metadata': [
@@ -329,16 +342,16 @@ grid_opts = {
 }
 
 ogc_service_md = {
-    'title': string_type,
-    'abstract': string_type,
-    'online_resource': string_type,
+    'title': str,
+    'abstract': str,
+    'online_resource': str,
     'contact': anything(),
-    'fees': string_type,
-    'access_constraints': string_type,
+    'fees': str,
+    'access_constraints': str,
     'keyword_list': [
         {
-            'vocabulary': string_type,
-            'keywords': [string_type],
+            'vocabulary': str,
+            'keywords': [str],
         }
     ],
 }
@@ -358,7 +371,7 @@ band_sources = {
 }
 
 mapproxy_yaml_spec = {
-    '__config_files__': anything(), # only used internaly
+    '__config_files__': anything(),  # only used internaly
     'globals': {
         'image': {
             'resampling_method': 'method',
@@ -388,7 +401,7 @@ mapproxy_yaml_spec = {
             'max_tile_limit': number(),
             'minimize_meta_requests': bool(),
             'concurrent_tile_creators': int(),
-            'link_single_color_images': bool(),
+            'link_single_color_images': one_of(bool(), 'symlink', 'hardlink'),
             's3': {
                 'bucket_name': str(),
                 'profile_name': str(),
@@ -404,10 +417,10 @@ mapproxy_yaml_spec = {
             'tile_size': [int()],
         },
         'srs': {
-          'axis_order_ne': [str()],
-          'axis_order_en': [str()],
-          'proj_data_dir': str(),
-          'preferred_src_proj': {anything(): [str()]},
+            'axis_order_ne': [str()],
+            'axis_order_en': [str()],
+            'proj_data_dir': str(),
+            'preferred_src_proj': {anything(): [str()]},
         },
         'tiles': {
             'expires_hours': number(),
@@ -422,7 +435,7 @@ mapproxy_yaml_spec = {
     },
     'caches': {
         anything(): {
-            required('sources'): one_of([string_type], band_sources),
+            required('sources'): one_of([str], band_sources),
             'name': str(),
             'grids': [str()],
             'cache_dir': str(),
@@ -437,13 +450,13 @@ mapproxy_yaml_spec = {
             'request_format': str(),
             'use_direct_from_level': number(),
             'use_direct_from_res': number(),
-            'link_single_color_images': bool(),
+            'link_single_color_images': one_of(bool(), 'symlink', 'hardlink'),
             'cache_rescaled_tiles': bool(),
             'upscale_tiles': int(),
             'downscale_tiles': int(),
             'refresh_before': time_spec,
             'watermark': {
-                'text': string_type,
+                'text': str,
                 'font_size': number(),
                 'color': one_of(str(), [number()]),
                 'opacity': number(),
@@ -479,7 +492,7 @@ mapproxy_yaml_spec = {
             'bbox_srs': [one_of(str(), {'bbox': [number()], 'srs': str()})],
             'image_formats': [str()],
             'attribution': {
-                'text': string_type,
+                'text': str,
             },
             'featureinfo_types': [str()],
             'featureinfo_xslt': {
@@ -508,7 +521,7 @@ mapproxy_yaml_spec = {
                     'featureinfo_out_format': str(),
                 },
                 'image': combined(image_opts, {
-                    'opacity':number(),
+                    'opacity': number(),
                     'transparent_color': one_of(str(), [number()]),
                     'transparent_color_tolerance': number(),
                 }),
@@ -523,28 +536,28 @@ mapproxy_yaml_spec = {
                 }
             }),
             'mapserver': combined(source_commons, {
-                    'wms_opts': {
-                        'version': str(),
-                        'map': bool(),
-                        'featureinfo': bool(),
-                        'legendgraphic': bool(),
-                        'legendurl': str(),
-                        'featureinfo_format': str(),
-                        'featureinfo_xslt': str(),
-                    },
-                    'image': combined(image_opts, {
-                        'opacity':number(),
-                        'transparent_color': one_of(str(), [number()]),
-                        'transparent_color_tolerance': number(),
-                    }),
-                    'supported_formats': [str()],
-                    'supported_srs': [str()],
-                    'forward_req_params': [str()],
-                    required('req'): {
-                        required('map'): str(),
-                        anything(): anything()
-                    },
-                    'mapserver': mapserver_opts,
+                'wms_opts': {
+                    'version': str(),
+                    'map': bool(),
+                    'featureinfo': bool(),
+                    'legendgraphic': bool(),
+                    'legendurl': str(),
+                    'featureinfo_format': str(),
+                    'featureinfo_xslt': str(),
+                },
+                'image': combined(image_opts, {
+                    'opacity': number(),
+                    'transparent_color': one_of(str(), [number()]),
+                    'transparent_color_tolerance': number(),
+                }),
+                'supported_formats': [str()],
+                'supported_srs': [str()],
+                'forward_req_params': [str()],
+                required('req'): {
+                    required('map'): str(),
+                    anything(): anything()
+                },
+                'mapserver': mapserver_opts,
             }),
             'tile': combined(source_commons, {
                 required('url'): str(),
@@ -552,7 +565,7 @@ mapproxy_yaml_spec = {
                 'image': image_opts,
                 'grid': str(),
                 'request_format': str(),
-                'origin': str(), # TODO: remove with 1.5
+                'origin': str(),  # TODO: remove with 1.5
                 'http': http_opts,
                 'on_error': on_error,
             }),
@@ -566,7 +579,7 @@ mapproxy_yaml_spec = {
                 'multithreaded': bool(),
             }),
             'arcgis': combined(source_commons, {
-               required('req'): {
+                required('req'): {
                     required('url'): str(),
                     'dpi': int(),
                     'layers': str(),
@@ -590,24 +603,26 @@ mapproxy_yaml_spec = {
     'layers': one_of(
         {
             anything(): combined(scale_hints, {
-                'sources': [string_type],
-                required('title'): string_type,
+                'sources': [str],
+                required('title'): str,
                 'legendurl': str(),
                 'md': wms_130_layer_md,
             })
         },
         recursive([combined(scale_hints, {
-            'sources': [string_type],
-            'tile_sources': [string_type],
+            'sources': [str],
+            'tile_sources': [str],
             'name': str(),
-            required('title'): string_type,
+            required('title'): str,
             'legendurl': str(),
+            'wmts_rest_legendurl': str(),
+            'wmts_kvp_legendurl': str(),
             'layers': recursive(),
             'md': wms_130_layer_md,
             'dimensions': {
                 anything(): {
-                    required('values'): [one_of(string_type, float, int)],
-                    'default': one_of(string_type, float, int),
+                    required('values'): [one_of(str, float, int)],
+                    'default': one_of(str, float, int),
                 }
             }
         })])
