@@ -24,7 +24,6 @@ import sys
 import textwrap
 import logging
 
-from mapproxy.compat import iteritems
 from mapproxy.config.loader import load_plugins
 from mapproxy.script.conf.app import config_command
 from mapproxy.script.defrag import defrag_command
@@ -47,6 +46,7 @@ def setup_logging(level=logging.INFO, format=None):
     ch.setFormatter(formatter)
     mapproxy_log.addHandler(ch)
 
+
 def serve_develop_command(args):
     parser = optparse.OptionParser("usage: %prog serve-develop [options] mapproxy.yaml")
     parser.add_option("-b", "--bind",
@@ -74,7 +74,6 @@ def serve_develop_command(args):
         #############################################\
         """))
 
-
     if options.debug:
         setup_logging(level=logging.DEBUG)
     else:
@@ -93,20 +92,21 @@ def serve_develop_command(args):
         try:
             from repoze.profile import ProfileMiddleware
             app = ProfileMiddleware(
-               app,
-               log_filename='/tmp/mapproxy_profile.log',
-               discard_first_request=True,
-               flush_at_shutdown=True,
-               path='/__profile__',
-               unwind=False,
+                app,
+                log_filename='/tmp/mapproxy_profile.log',
+                discard_first_request=True,
+                flush_at_shutdown=True,
+                path='/__profile__',
+                unwind=False,
             )
             print('Installed profiler at /__profile__')
         except ImportError:
             pass
 
     run_simple(host, port, app, use_reloader=True, processes=1,
-        threaded=True, passthrough_errors=True,
-        extra_files=extra_files)
+               threaded=True, passthrough_errors=True,
+               extra_files=extra_files)
+
 
 def serve_multiapp_develop_command(args):
     parser = optparse.OptionParser("usage: %prog serve-multiapp-develop [options] projects/")
@@ -141,7 +141,7 @@ def serve_multiapp_develop_command(args):
     app = make_wsgi_app(mapproxy_conf_dir, debug=options.debug)
 
     run_simple(host, port, app, use_reloader=True, processes=1,
-        threaded=True, passthrough_errors=True)
+               threaded=True, passthrough_errors=True)
 
 
 def parse_bind_address(address, default=('localhost', 8080)):
@@ -169,6 +169,7 @@ def create_command(args):
     cmd = CreateCommand(args)
     cmd.run()
 
+
 class CreateCommand(object):
     templates = {
         'base-config': {},
@@ -179,14 +180,14 @@ class CreateCommand(object):
     def __init__(self, args):
         parser = optparse.OptionParser("usage: %prog create [options] [destination]")
         parser.add_option("-t", "--template", dest="template",
-            help="Create a configuration from this template.")
+                          help="Create a configuration from this template.")
         parser.add_option("-l", "--list-templates", dest="list_templates",
-            action="store_true", default=False,
-            help="List all available configuration templates.")
+                          action="store_true", default=False,
+                          help="List all available configuration templates.")
         parser.add_option("-f", "--mapproxy-conf", dest="mapproxy_conf",
-            help="Existing MapProxy configuration (required for some templates).")
+                          help="Existing MapProxy configuration (required for some templates).")
         parser.add_option("--force", dest="force", action="store_true",
-            default=False, help="Force operation (e.g. overwrite existing files).")
+                          default=False, help="Force operation (e.g. overwrite existing files).")
 
         self.options, self.args = parser.parse_args(args)
         self.parser = parser
@@ -245,7 +246,7 @@ class CreateCommand(object):
         app_template = io.open(os.path.join(template_dir, 'config.wsgi'), encoding='utf-8').read()
         with io.open(app_filename, 'w', encoding='utf-8') as f:
             f.write(app_template % {'mapproxy_conf': mapproxy_conf,
-                'here': os.path.dirname(mapproxy_conf)})
+                                    'here': os.path.dirname(mapproxy_conf)})
 
         return 0
 
@@ -257,7 +258,7 @@ class CreateCommand(object):
         template_dir = self.template_dir()
 
         for filename in ('mapproxy.yaml', 'seed.yaml',
-            'full_example.yaml', 'full_seed_example.yaml'):
+                         'full_example.yaml', 'full_seed_example.yaml'):
             to = os.path.join(outdir, filename)
             from_ = os.path.join(template_dir, filename)
             if os.path.exists(to) and not self.options.force:
@@ -282,6 +283,7 @@ class CreateCommand(object):
 
         return 0
 
+
 commands = {
     'serve-develop': {
         'func': serve_develop_command,
@@ -313,7 +315,7 @@ commands = {
     },
     'autoconfig': {
         'func': config_command,
-        'help': 'Create config from WMS capabilities.'
+        'help': 'Create config from WMS capabilities or a Geopackage file.'
     },
     'defrag-compact-cache': {
         'func': defrag_command,
@@ -366,19 +368,20 @@ def print_items(data, title='Commands'):
 
     if title:
         print('%s:' % (title, ), file=sys.stdout)
-    for name, item in iteritems(data):
+    for name, item in data.items():
         help = item.get('help', '')
         name = ('%%-%ds' % name_len) % name
         if help:
             help = '  ' + help
         print('  %s%s' % (name, help), file=sys.stdout)
 
+
 def main():
 
     load_plugins()
 
     parser = NonStrictOptionParser("usage: %prog COMMAND [options]",
-        add_help_option=False)
+                                   add_help_option=False)
     options, args = parser.parse_args()
 
     if len(args) < 1 or args[0] in ('--help', '-h'):
@@ -402,5 +405,6 @@ def main():
     args = sys.argv[0:1] + sys.argv[2:]
     commands[command]['func'](args)
 
+
 if __name__ == '__main__':
     main()
