@@ -24,7 +24,6 @@ from contextlib import contextmanager
 from lxml import etree
 
 from mapproxy.test import mocker
-from mapproxy.compat import string_type, PY2
 
 
 class Mocker(object):
@@ -35,21 +34,26 @@ class Mocker(object):
     `setup` will initialize a `mocker.Mocker`. The `teardown` method
     will run ``mocker.verify()``.
     """
+
     def setup_method(self):
         self.mocker = mocker.Mocker()
+
     def expect_and_return(self, mock_call, return_val):
         """
         Register a return value for the mock call.
         :param return_val: The value mock_call should return.
         """
         self.mocker.result(return_val)
+
     def expect(self, mock_call):
         return mocker.expect(mock_call)
+
     def replay(self):
         """
         Finish mock-record phase.
         """
         self.mocker.replay()
+
     def mock(self, base_cls=None):
         """
         Return a new mock object.
@@ -59,9 +63,11 @@ class Mocker(object):
         if base_cls:
             return self.mocker.mock(base_cls)
         return self.mocker.mock()
+
     def teardown_method(self):
         self.mocker.verify()
 
+
 class TempFiles(object):
     """
     This class is a context manager for temporary files.
@@ -72,6 +78,7 @@ class TempFiles(object):
     >>> for f in tmp:
     ...     assert not os.path.exists(f)
     """
+
     def __init__(self, n=1, suffix='', no_create=False):
         self.n = n
         self.suffix = suffix
@@ -93,14 +100,18 @@ class TempFiles(object):
                 os.remove(tmp_file)
         self.tmp_files = []
 
+
 class TempFile(TempFiles):
     def __init__(self, suffix='', no_create=False):
         TempFiles.__init__(self, suffix=suffix, no_create=no_create)
+
     def __enter__(self):
         return TempFiles.__enter__(self)[0]
 
+
 class LogMock(object):
     log_methods = ('info', 'debug', 'warn', 'error', 'fail')
+
     def __init__(self, module, log_name='log'):
         self.module = module
         self.orig_logger = None
@@ -125,7 +136,6 @@ class LogMock(object):
         assert msg in log_msg.lower(), "expected string '%s' in log message '%s'" % \
             (msg, log_msg)
 
-
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.module.log = self.orig_logger
 
@@ -163,7 +173,7 @@ def validate_with_dtd(doc, dtd_name, dtd_basedir=None):
     dtd_filename = os.path.join(dtd_basedir, dtd_name)
     with open(dtd_filename, 'rb') as schema:
         dtd = etree.DTD(schema)
-        if isinstance(doc, (string_type, bytes)):
+        if isinstance(doc, (str, bytes)):
             xml = etree.XML(doc)
         else:
             xml = doc
@@ -171,6 +181,7 @@ def validate_with_dtd(doc, dtd_name, dtd_basedir=None):
         print(dtd.error_log.filter_from_errors())
         return is_valid
 
+
 def validate_with_xsd(doc, xsd_name, xsd_basedir=None):
     if xsd_basedir is None:
         xsd_basedir = os.path.join(os.path.dirname(__file__), 'schemas')
@@ -180,7 +191,7 @@ def validate_with_xsd(doc, xsd_name, xsd_basedir=None):
     with open(xsd_filename, 'rb') as schema:
         xsd = etree.parse(schema)
         xml_schema = etree.XMLSchema(xsd)
-        if isinstance(doc, (string_type, bytes)):
+        if isinstance(doc, (str, bytes)):
             xml = etree.XML(doc)
         else:
             xml = doc
@@ -188,6 +199,7 @@ def validate_with_xsd(doc, xsd_name, xsd_basedir=None):
         print(xml_schema.error_log.filter_from_errors())
         return is_valid
 
+
 class XPathValidator(object):
     def __init__(self, doc):
         self.xml = etree.XML(doc)
@@ -199,6 +211,7 @@ class XPathValidator(object):
                 assert expected(self.xml.xpath(xpath)[0])
             else:
                 assert self.xml.xpath(xpath)[0] == expected
+
     def xpath(self, xpath):
         return self.xml.xpath(xpath)
 
@@ -216,14 +229,10 @@ def strip_whitespace(data):
 
 @contextmanager
 def capture(bytes=False):
-    if PY2:
-        from StringIO import StringIO
+    if bytes:
+        from io import BytesIO as StringIO
     else:
-        if bytes:
-            from io import BytesIO as StringIO
-        else:
-            from io import StringIO
-
+        from io import StringIO
 
     backup_stdout = sys.stdout
     backup_stderr = sys.stderr
@@ -244,4 +253,3 @@ def capture(bytes=False):
     finally:
         sys.stdout = backup_stdout
         sys.stderr = backup_stderr
-
